# Project Description

# Release History


## version==0.0.7
sparrow_parcel 的 Transfer 实体去掉揽收包裹数量字段  

## version==0.0.7
修改一些bug  

## version==0.0.6
将 sparrow_shipping 维护至本项目  
将 remote_call 维护至本项目
```
需要新增以下环境变量
RUN_ENV
export SPARROW_ORDER_APP_LABEL=sparrow_orders
export SPARROW_ORDER_AFS_APP_LABEL=sparrow_orders_afs
export SPARROW_DISTRIBUTE_APP_LABEL=sparrow_distribute
export SPARROW_AFTERSALE_APP_LABEL=sparrow_aftersale
export SPARROW_EXCHANGE_APP_LABEL=sparrow_exchange
export SPARROW_PROMOTIONS_APP_LABEL=sparrow_promotions
export SPARROW_DISSTORAGE_APP_LABEL=sparrow_disstorage
export SPARROW_PARCEL_APP_LABEL=sparrow_parcel
export SPARROW_SHIPPING_APP_LABEL=sparrow_shipping
SC_SPARROW_CORE_GO_SVC
SC_SPARROW_CORE_SVC
SC_SPARROW_PRODUCT_SVC

settings 里面需要添加以下配置
SF_PAYCARD_NUMBER_MAILE
SHIPPING_URL_SF_USERCODE
SHIPPING_URL_SF_CHECKCODE
SF_PAYCARD_NUMBER_HANGUANG
SHIPPING_CREATE_ORDER_SENDER_NO_YZPY
SHIPPING_CREATE_ORDER_ECOMMERCE_NO_YZPY
SHIPPING_CREATE_ORDER_ECCOMPANYID_YZPY
SHIPPING_CREATE_ORDER_SECRET_YZPY
```

## version==0.0.5
############# sparrow-order-lib 使用配置 ############
export SPARROW_ORDER_APP_LABEL=sparrow_orders
export SPARROW_ORDER_AFS_APP_LABEL=sparrow_orders_afs
export SPARROW_DISTRIBUTE_APP_LABEL=sparrow_distribute
export SPARROW_AFTERSALE_APP_LABEL=sparrow_aftersale
export SPARROW_EXCHANGE_APP_LABEL=sparrow_exchange
export SPARROW_PROMOTIONS_APP_LABEL=sparrow_promotions
export SPARROW_DISSTORAGE_APP_LABEL=sparrow_disstorage
export SPARROW_PARCEL_APP_LABEL=sparrow_parcel

## version==0.0.4
将 sparrow_disstorage 维护至本项目  
新增项目 sparrow_parcel  
该版本尝试将 exceptions 维护至本项目  
```
需要新增以下环境变量
SPARROW_DISSTORAGE_APP_LABEL
SPARROW_PARCEL_APP_LABEL
```

## version==0.03
将所有公共 models 维护至本项目。
```
需要以下环境变量:  
SPARROW_ORDER_APP_LABEL
SPARROW_ORDER_AFS_APP_LABEL
SPARROW_DISTRIBUTE_APP_LABEL  
SPARROW_AFTERSALE_APP_LABEL
SPARROW_EXCHANGE_APP_LABEL
SPARROW_PROMOTIONS_APP_LABEL
```

settings 要包含以下配置
```
PHONE_NUMBER_REGEX
```

## version==0.02
测试 models 维护至 sparrow-order-lib 可行性

## version==0.01
core.db_tool.query
